#
# spec file for package libzpc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libzpc
Version:        1.3.0
Release:        2.1
Summary:        IBM Z Protected-key Crypto library
License:        MIT
Group:          Productivity/Security
URL:            https://github.com/opencryptoki/libzpc
Source:         https://github.com/opencryptoki/libzpc/archive/refs/tags/v%{version}.tar.gz#/libzpc-%{version}.tar.gz
BuildRequires:  cmake >= 3.10
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libjson-c-devel
BuildRequires:  texlive-bibtex-bin
ExclusiveArch:  s390x

%description
The IBM Z Protected-key Crypto library libzpc is a library targeting
the 64-bit Linux on IBM Z (s390x) platform. It provides interfaces for
cryptographic primitives. The underlying implementations make use of
z/Architecture's performance-boosting hardware support and its
protected-key feature which ensures that key material is never present
in main memory at any time.

%package -n libzpc1
Summary:        IBM Z Protected-key Crypto library
Group:          System/Libraries

%description -n libzpc1
This package contains the shared library to work with the
IBM protected-key cryptography hardware

%package devel
Summary:        Header files for the IBM Z Protected-key Crypto library
Group:          Productivity/Security
Requires:       libzpc1 = %{version}-%{release}

%description devel
This package provides the header files and symbolic link to the
shared library for the libzpc RPM.

%prep
%autosetup -p1

%build
%cmake -DBUILD_DOC=ON
%make_build

%install
cd build
%make_install

%post -n libzpc1 -p /sbin/ldconfig

%postun -n libzpc1 -p /sbin/ldconfig

%files -n libzpc1
%doc README.md
%license LICENSE
%{_libdir}/%{name}.so.1
%{_libdir}/%{name}.so.%{version}

%files devel
%dir %{_includedir}/zpc
%{_includedir}/zpc/*.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Tue Feb 18 2025 Nikolay Gueorguiev <nikolay.gueorguiev@suse.com>
- License update to MIT
* Thu Feb 13 2025 Nikolay Gueorguiev <nikolay.gueorguiev@suse.com>
- Upgrade libzpc to version 1.3.0 (jsc#PED-11163, jsc#PED-10294)
  - [FEATURE] Support for Ultravisor retrievable secrets
  - [PATCH] Handle CCA cipher key token with Encrypted V0 payload
  - [PATCH] bug fixes
* Mon Jan 15 2024 Nikolay Gueorguiev <nikolay.gueorguiev@suse.com>
- Upgrade libzpc to version 1.2.0 (jsc#PED-3335)
  * Support for get/set intermediate iv for CBC and XTS
  * Support for internal iv for GCM
  * Exploit KBLOB2PROTK3 ioctl for clear AES and EC keys
  * Fix AES EP11 version 6 key support for generate and import_clear
* Wed Sep 20 2023 Nikolay Gueorguiev <nikolay.gueorguiev@suse.com>
- Version 1.1.1 (jsc#PED-5214)
  * Exploit PKEY_KBLOB2PROTK2 for AES EP11 version 6 keys
* Wed Feb  8 2023 Mark Post <mpost@suse.com>
- Upgrade to version 1.1.0 (jsc#PED-582)
  * Implements an ECC-KEY API : `zpc/ecc_key.h`.
  * Implements an ECDSA-CTX API : `zpc/ecdsa_ctx.h`.
* Tue Sep 13 2022 Mark Post <mpost@suse.com>
- Upgrade to version 1.0.1 (jsc#PED-582)
  * Updated spec file for rpm build
- Removed obsolete libzpc-sles15p4-mark-stack-nonexec.patch
- Updated spec file to use %%{name} and %%{version} variables in
  more places.
* Wed Apr 27 2022 Marcus Meissner <meissner@suse.com>
- use source url
* Tue Nov  2 2021 Marcus Meissner <meissner@suse.com>
- libzpc-sles15p4-mark-stack-nonexec.patch: note the asssembler as
  non execstack
- libzpc-rpmlintrc removed
* Mon Nov  1 2021 Mark Post <mpost@suse.com>
- Cleaned up the wording in the description. Updated the
  summaries to actually reflect the contents of the packages.
- Changed the %%setup macro to use $autosetup instead.
- Added a BuildRequires for texlive-bibtex-bin
* Tue Oct 19 2021 Mark Post <mpost@suse.com>
- Initial version 1.0.0 (jsc#SLE-18746)
